##  Subscription-Based Permissions
In the Subscription-based Permissions section, you can configure permissions for specific fact sheet attributes based on the user's subscription type (observer, responsible, or accountable). This provides an additional layer of access control. The user's subscription type is checked on a fact sheet level. To learn more about subscription types, see [Subscription Type](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet subscription assigns responsibility and accountability to users for maintaining data. Learn about fact sheet subscriptions, including types, roles, and how to assign and subscribe to fact sheets to promote stakeholder involvement and ensure data accuracy and completeness.").
For example, you may want only users with a responsible subscription type to edit the Budget / Costs Description attribute on initiative fact sheets. You can configure an advanced permission to check the user's subscription type before allowing edits. If a user is subscribed to a fact sheet as responsible, they can edit the attribute. Users with observer or accountable subscriptions cannot make edits.
Subscription-based quality seal permissions are configured by default. While viewers and members usually cannot update the quality seal, this advanced option allows users with a responsible or accountable subscription type to update it.
